@@ -1,4 +1,7 @@
-#!/usr/bin/env perl 
+#!/usr/bin/perl 
+
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
+    if 0; # not running under some shell
 #!d:\perl\bin\perl.exe 
 #
 # Filename: stubmaker.pl
@@ -8,7 +11,8 @@
 # Copyright (C) 2005 Byrne Reese
 #
 # Usage:
-#!/usr/bin/perl
+#    stubmaker.pl -[vd] <WSDL URL>
+###################################################
 
 use SOAP::Lite;
 use Getopt::Long;
